@@ -142,4 +142,26 @@ def two_way(operation, opposite=False, iterators=False):
                                 succeeded[a].add(b)
                         except:
                             failed[a].add(b)
-    return [{'succeeded': succeeded}]
\ No newline at end of file
+    return [{'succeeded': succeeded}]
+
+
+def operator_check(left_argument, right_argument, show_failed=False):
+    import warnings
+    warnings.filterwarnings("ignore")
+    failed = set()
+    succeeded = set()
+    operators = [':', ',', ';', '+', '-', '*', '/', '|', '&', '<', '>', '=',
+                 '.', '%', '==', '!=', '<=', '>=', '~', '^', '<<',
+                 '>>', '**', '+=', '-=', '*=', '/=', '%=', '&=', '|=', '^=',
+                 '<<=', '>>=', '**=', '//', '//=', '@', '@=', '->', '...',
+                 ':=']
+    for operator in operators:
+        try:
+            x = eval(f'{left_argument} {operator} {right_argument}')
+            succeeded.add(operator)
+        except:
+            failed.add(operator)
+    returned_dictionary = {'succeeded': succeeded}
+    if show_failed:
+        returned_dictionary['failed'] = failed
+    return returned_dictionary
